@@ -48,7 +48,6 @@ plotTimeSeries <- function(timestamp, series, start.time=min(timestamp),
     end.time=max(timestamp), title="time series", y.label="series") {
 
   stopifnot(length(timestamp) == length(series))
-  logger(paste("plotTimeSeries between", start.time, "and", end.time))
 
   df <- data.frame(ts=timestamp, val=series)
   df <- df[df$ts >= start.time & df$ts <= end.time, ]
@@ -221,7 +220,6 @@ plotPriceLevels <- function(depth, spread=NULL, trades=NULL,
     unchanged.prices <- unchanged.prices[unchanged]
     depth.filtered <- depth.filtered[!depth.filtered$price 
         %in% unchanged.prices, ]
-    logger(paste("removed", length(unchanged.prices), "unchanged depths"))
   }
    
   depth.filtered[depth.filtered$volume==0, ]$volume <- NA
@@ -485,14 +483,12 @@ plotVolumeMap <- function(events,
     events <- events[events$volume >= volume.from | events$volume == 0, ]
   else {
     lim <- quantile(events$volume, 0.0001)
-    logger(paste("lower volume limit =", lim))
     events <- events[events$volume >= lim, ]
   }
   if(!is.null(volume.to))
     events <- events[events$volume <= volume.to, ]
   else {
     lim <- quantile(events$volume, 0.9999)
-    logger(paste("uppper volume limit =", lim))
     events <- events[events$volume <= lim, ]
   }
 
@@ -501,7 +497,7 @@ plotVolumeMap <- function(events,
   col.pal <- c("#0000ff", "#ff0000")
   names(col.pal) <- c("bid", "ask")
   p <- ggplot(data=events, mapping=aes_string(x="timestamp", y="volume"))
-  p <- p + geom_point(mapping=aes_string(colour="direction"), size=1, shape=15)
+  p <- p + geom_point(mapping=aes_string(colour="direction"), size=0.5, shape=15)
   p <- p + scale_colour_manual(values=col.pal, name="direction     \n")
   p <- p + scale_y_continuous(name="cancelled volume",
       labels=function(y) sprintf("%5s", sprintf("%.2f", y)),
@@ -568,9 +564,6 @@ plotCurrentDepth <- function(order.book,
     bid.quantiles <- with(bids, price[volume >= quantile(volume, 0.99)])
     ask.quantiles <- with(asks, price[volume >= quantile(volume, 0.99)])
 
-    logger(paste("bid quantiles =", paste(bid.quantiles, collapse=", "),
-                 "ask quantiles =", paste(ask.quantiles, collapse=", ")))
-
     p <- p + geom_vline(xintercept=bid.quantiles, colour="#222222")
     p <- p + geom_vline(xintercept=ask.quantiles, colour="#222222")
   }
@@ -630,13 +623,10 @@ plotVolumePercentiles <- function(depth.summary,
   # see: http://stackoverflow.com/questions/9439256
   liquidity <- NULL; percentile <- NULL 
         
-  logger(paste("plot depth percentiles between", start.time, "and", end.time))
-
   bid.names <- paste0("bid.vol", seq(from=25, to=500, by=25), "bps")
   ask.names <- paste0("ask.vol", seq(from=25, to=500, by=25), "bps")
 
   td <- difftime(end.time, start.time, units="secs")
-  logger(paste("time range =", td, "secs"))
   td <- round(as.numeric(td))
 
   # resolution: if(td > 15 minutes, minute ticks, else seconds. 
@@ -644,7 +634,6 @@ plotVolumePercentiles <- function(depth.summary,
   ob.percentiles <- depth.summary[depth.summary$timestamp 
       >= start.time-ifelse(frequency == "mins", 60, 1) & depth.summary$timestamp
       <= end.time, c("timestamp", bid.names, ask.names)]
-  logger(paste("aggregating to", frequency, "intervals"))
 
   # remove duplicates (take last entry) (for zoo to work)
   ob.percentiles <- ob.percentiles[!duplicated(ob.percentiles$timestamp, 
@@ -655,11 +644,10 @@ plotVolumePercentiles <- function(depth.summary,
 
   # intervals truncated to frequency
   intervals <- as.POSIXct(trunc(time(zoo.obj), frequency))
-  logger(paste("aggregation:", min(intervals), ":", max(intervals), "by =", 
-      frequency))
 
   # use zoo to aggregate by intervals. take mean of each interval.
   aggregated <- aggregate(zoo.obj, intervals, mean)
+
   ob.percentiles <- data.frame(timestamp=unique(intervals)+ifelse(frequency == 
       "mins", 60, 1), aggregated, row.names=NULL)
 
@@ -678,40 +666,37 @@ plotVolumePercentiles <- function(depth.summary,
       value.name="liquidity")
   melted.asks$percentile <- factor(melted.asks$percentile, rev(ask.names))
   melted.asks$liquidity <- volume.scale*(melted.asks$liquidity)
+
   melted.bids <- melt(ob.percentiles, id.vars="timestamp", 
       measure.vars=bid.names, variable.name="percentile", 
       value.name="liquidity")
-  melted.bids$percentile <- factor(melted.bids$percentile, bid.names)
+  melted.bids$percentile <- factor(melted.bids$percentile, rev(bid.names))
   melted.bids$liquidity <- volume.scale*(melted.bids$liquidity)
 
   col.pal <- colorRampPalette(c("#f92b20", "#fe701b", "#facd1f", "#d6fd1c", 
       "#65fe1b", "#1bfe42", "#1cfdb4", "#1fb9fa", "#1e71fb", "#261cfd"))(20)
   col.pal <- c(col.pal, col.pal)
+
   breaks <- c(rev(paste0("ask.vol", sprintf("%03d", seq(from=50, to=500, 
       by=50)), "bps")), paste0("bid.vol", sprintf("%03d", seq(from=50, 
       to=500, by=50)), "bps"))
+
   legend.names <- c(rev(paste0("+", sprintf("%03d", seq(from=50, to=500, 
-      by=50)), "bps")), paste0("-", sprintf("%03d", seq(from=50, to=500, 
+      by=50)), "bps")), paste0("-", sprintf("%03d", seq(from=50, to=500,
       by=50)), "bps"))
 
+  # seperate percentiles by black line
+  if(perc.line) pl=0.1 else pl=0
+
   # top stack (asks)  
   p <- ggplot(data=melted.asks, 
       mapping=aes(x=timestamp, y=liquidity, fill=percentile))
-  p <- p + geom_area(position="stack")
+  p <- p + geom_area(position="stack", linetype=1, size=pl, colour="#000000")
 
   # bottom stack (bids)
   p <- p + geom_area(data=melted.bids, 
       mapping=aes(x=timestamp, y=-liquidity, fill=percentile), 
-      position="stack")
-    
-  # seperate percentiles by black line    
-  if(perc.line) {
-    p <- p + geom_line(mapping=aes(ymax=0), position="stack", col="#000000",
-        size=0.1)
-    p <- p + geom_line(data=melted.bids, 
-        mapping=aes(x=timestamp, y=-liquidity, ymax=0), 
-        position="stack", col="#000000", size=0.1)
-  }
+      position="stack", linetype=1, size=pl, colour="#000000")
 
   # colour  
   p <- p + scale_fill_manual(values=col.pal, breaks=breaks, labels=legend.names,
@@ -766,7 +751,6 @@ plotEventsHistogram <- function(events,
     bw=NULL) {
  
   stopifnot(val == "volume" || val == "price")
-  logger(paste("from =", start.time, "to =", end.time))
     
   events <- events[events$timestamp >= start.time
                  & events$timestamp <= end.time, ]
